summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/fullscreen_exit_bubble_gtk.h
diff options
context:
space:
mode:
authortony@chromium.org <tony@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-17 21:24:33 +0000
committertony@chromium.org <tony@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-17 21:24:33 +0000
commit6d3b1f2749528cfe7152a2bc3e41a17dceac51dc (patch)
tree7bb8d3ca3ced9ba3a66763781751703607749b79 /chrome/browser/gtk/fullscreen_exit_bubble_gtk.h
parent67f7191aa0be7791da0c4d9f913b2a90c4eb4dae (diff)
downloadchromium_src-6d3b1f2749528cfe7152a2bc3e41a17dceac51dc.zip
chromium_src-6d3b1f2749528cfe7152a2bc3e41a17dceac51dc.tar.gz
chromium_src-6d3b1f2749528cfe7152a2bc3e41a17dceac51dc.tar.bz2
Make the fullscreen exit bubble slide away when it hides.
BUG=8405 Review URL: http://codereview.chromium.org/507042 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@34877 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gtk/fullscreen_exit_bubble_gtk.h')
-rw-r--r--chrome/browser/gtk/fullscreen_exit_bubble_gtk.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/chrome/browser/gtk/fullscreen_exit_bubble_gtk.h b/chrome/browser/gtk/fullscreen_exit_bubble_gtk.h
index f5c3c80..44b3ac0 100644
--- a/chrome/browser/gtk/fullscreen_exit_bubble_gtk.h
+++ b/chrome/browser/gtk/fullscreen_exit_bubble_gtk.h
@@ -8,7 +8,7 @@
#include <gtk/gtk.h>
#include "base/timer.h"
-#include "chrome/common/owned_widget_gtk.h"
+#include "chrome/browser/gtk/slide_animator_gtk.h"
typedef struct _GtkFloatingContainer GtkFloatingContainer;
@@ -23,6 +23,10 @@ class FullscreenExitBubbleGtk {
void InitWidgets();
private:
+ GtkWidget* widget() const {
+ return slide_widget_->widget();
+ }
+
// Hide the exit bubble.
void Hide();
@@ -36,8 +40,8 @@ class FullscreenExitBubbleGtk {
// A pointer to the floating container that is our parent.
GtkFloatingContainer* container_;
- // The top widget of the exit bubble.
- OwnedWidgetGtk alignment_;
+ // The widget that animates the slide-out of fullscreen exit bubble.
+ scoped_ptr<SlideAnimatorGtk> slide_widget_;
// The timer that does the initial hiding of the exit bubble.
base::OneShotTimer<FullscreenExitBubbleGtk> initial_delay_;